@@ -37,7 +37,7 @@
        Keith Owens <kaos@ocs.com.au> April 2000.
    */
 
-#ident "$Id: depmod.c 1.19 Sun, 13 Aug 2000 06:45:56 -0700 kaos $"
+#ident "$Id: depmod.c 1.22 Sun, 10 Sep 2000 11:25:29 +1100 kaos $"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -64,6 +64,7 @@
 
 #define ALLOC_MODULE	5000	/* Number of modules we can handle... */
 #define ALLOC_SYM	10000	/* Number of symbols allocated per chunk */
+#define MAX_MAP_SYM	100000	/* Maximum number of symbols in map */
 
 typedef struct SYMBOL{
 	struct SYMBOL *next;	/* List connected via hashing */
@@ -370,7 +371,8 @@ static int loadobj(const char *objname, int ignore_suffix)
 	for (i = 0; i < HASH_BUCKETS; ++i) {
 		for (objsym = f->symtab[i]; objsym; objsym = objsym->next) {
 			if (objsym->secidx == SHN_UNDEF) {
-				if (ELFW(ST_BIND)(objsym->info) != STB_WEAK) {
+				if (ELFW(ST_BIND)(objsym->info) != STB_WEAK &&
+				    objsym->r_type /* assumes that R_arch_NONE is always 0 on all arch */) {
 					undefs[n_undefs++] = addsym(objsym->name,
 								    mod,
 								    SYM_UNDEF,
@@ -490,7 +492,7 @@ static int addksyms(char *file_syms)
 {
 	FILE *fp;
 	MODULE *mod = modules + n_modules++;
-	SYMBOL *symtab[10000];
+	SYMBOL *symtab[MAX_MAP_SYM];
 	struct module_symbol *ksym;
 	unsigned int so_far = 0;
 	int is_mapfile = 0;
@@ -565,7 +567,7 @@ static int addksyms(char *file_syms)
 					continue;
 				p = strtok(NULL, " \t\n");
 			}
-			assert(n_syms < 10000);
+			assert(n_syms < MAX_MAP_SYM);
 			symtab[n_syms++] = addsym(p, mod, SYM_DEFINED, 0);
 		}
 		fclose(fp);
@@ -574,7 +576,7 @@ static int addksyms(char *file_syms)
 			return -1;
 
 		for (ksym = ksyms; so_far < nksyms; ++so_far, ksym++) {
-			assert(n_syms < 10000);
+			assert(n_syms < MAX_MAP_SYM);
 			symtab[n_syms++] = addsym((char *)ksym->name, mod, SYM_DEFINED, 0);
 		}
 	}
@@ -615,7 +617,7 @@ static void prtdepend(const char *pdepfile, const char *ppcimapfile, char *base_
 		}
 	}
 
-	skipchars = (base_dir ? strlen(base_dir) : 0);
+	skipchars = strlen(base_dir);
 	tbdep = (MODULE **)alloca(sizeof(MODULE) * n_modules);
 
 	ptmod = modules;
@@ -793,7 +795,7 @@ int DEPMOD_MAIN(int argc, char **argv)
 	int o;
 	char *conf_file = NULL;
 	char *file_syms = NULL;
-	char *base_dir = NULL;
+	char *base_dir = "";
 	int ignore_suffix = 0;	/* Ignore genksyms suffix on resolve? */
 
 	struct option long_opts[] = {
