@@ -1562,7 +1562,7 @@ int main(int argc, char *argv[])
 	}
 	/* else */
 
-	if (config_read(1, NULL, NULL, conf_file) == -1)
+	if (config_read(1, NULL, "", conf_file) == -1)
 		return -1;
 	/* else */
 	new_NODE("null", "null", &in_depfile);
