@@ -3,14 +3,12 @@
  */
 
 /*
- * tbpath and tbtype are used to build the complete set of paths for
- * finding modules.
+ * tbpath and tbtype are used to build the complete set of paths for finding
+ * modules, but only when we search for individual directories, they are not
+ * used for [boot] and [toplevel] searches.
  */
 static char *tbpath[] =
 {
-	"/lib/modules/VERSION",	/* just a placeholder, look at config_read */
-	"/lib/modules/KVERSION",/* just a placeholder, look at config_read */
-	"/lib/modules/default",
 	"/lib/modules",
 	NULL			/* marks the end of the list! */
 };
